# text_menu

A small facility for making menus in a terminal.

## Requirements

- Runs in standard terminals.
- Uses single key entry for menu choices.
- Can be used to either:
    - Read menus from a JSON file or
    - Be passed JSON as parameter.
- Will recognize default choices that only require "Enter."
- Menu choices may be de-activated according to circumstances.

## Possible future enhancements:

- Use of library to get fancy colors. (colorama?)

